package net.sf.itcb.common.portlet.util;

import java.util.Map;

import javax.portlet.PortletRequest;

import org.apache.log4j.MDC;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContext;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.userdetails.UserDetails;

/**
 * This class defines in which portal the portlet is launched and delegate to the dedicated {@link PortalAdapter} class the transformation of user... data.<br/>
 * Mapping is done by the map <code>portalAdapters</code> injected by Spring.
 * 
 * This class is not finished yet such as the user management.
 * 
 * @author Pierre Le Roux
 */
public class PortalAdapterUtilImpl implements PortalAdapterUtil {

	private static final long serialVersionUID = 1L;
	
	protected static String MDC_USER_KEY ="user";
	
	private Map<String, PortalAdapter> portalAdapters;
	
	protected final Logger log = LoggerFactory.getLogger(getClass());
	
	public PortalAdapterUtilImpl(Map<String, PortalAdapter> portalAdapters) {
		this.portalAdapters = portalAdapters;
	}

	public void storeUserInContext(PortletRequest request) {
		PortalAdapter portalAdapter = portalAdapters.get(request.getClass().getName());
		
		UserDetails user = portalAdapter.getUser(request);
		SecurityContext securityContext = SecurityContextHolder.getContext();
		if(user != null) {
			securityContext.setAuthentication(new UsernamePasswordAuthenticationToken(user.getUsername(),user.getPassword(), user.getAuthorities()));
			MDC.put(MDC_USER_KEY, user.getUsername());
			log.debug("Logged in user : {}", user.getUsername());
		}
	}

	@Override
	public void storeLoggedUserInContext(Authentication user) {
		SecurityContext securityContext = SecurityContextHolder.getContext();
		if(user != null) {
			securityContext.setAuthentication(user);
			MDC.put(MDC_USER_KEY, user.getName());
			log.debug("Logged in user : {}", user.getName());
		}
		else {
			securityContext.setAuthentication(null);
			MDC.put(MDC_USER_KEY, "");
			log.debug("Logged in user : {}", "");
		}
		
	}

}
